Stan Math Library: stan/math/prim/mat/fun/csr_to_dense_matrix.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
csr_to_dense_matrix.hpp File Reference
`#include <stan/math/prim/mat/err/check_range.hpp>`
`#include <stan/math/prim/mat/fun/csr_u_to_z.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/dot_product.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::csr_to_dense_matrix (const int &m, const int &n, const Eigen::Matrix< T, Eigen::Dynamic, 1 > &w, const std::vector< int > &v, const std::vector< int > &u)
| Construct a dense Eigen matrix from the CSR format components. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.